@@ -8,5 +8,5 @@
 		$('time[data-time-ago]').timeago();
 	};
 	$(fn);
-	$(document).on('turbolinks:load page:load ajax:success', fn);
+	$(document).on('turbolinks:load page:load ajax:success ajaxSuccess', fn);
 })(jQuery);
